<?php

namespace Chemical\Import\Policies;

use Litepie\User\Contracts\UserPolicy;
use Chemical\Import\Models\Import;

class ImportPolicy
{

    /**
     * Determine if the given user can view the import.
     *
     * @param UserPolicy $user
     * @param Import $import
     *
     * @return bool
     */
    public function view(UserPolicy $user, Import $import)
    {
        if ($user->canDo('import.import.view') && $user->isAdmin()) {
            return true;
        }

        return $import->user_id == user_id() && $import->user_type == user_type();
    }

    /**
     * Determine if the given user can create a import.
     *
     * @param UserPolicy $user
     * @param Import $import
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('import.import.create');
    }

    /**
     * Determine if the given user can update the given import.
     *
     * @param UserPolicy $user
     * @param Import $import
     *
     * @return bool
     */
    public function update(UserPolicy $user, Import $import)
    {
        if ($user->canDo('import.import.edit') && $user->isAdmin()) {
            return true;
        }

        return $import->user_id == user_id() && $import->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given import.
     *
     * @param UserPolicy $user
     * @param Import $import
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Import $import)
    {
        return $import->user_id == user_id() && $import->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given import.
     *
     * @param UserPolicy $user
     * @param Import $import
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Import $import)
    {
        if ($user->canDo('import.import.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given import.
     *
     * @param UserPolicy $user
     * @param Import $import
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Import $import)
    {
        if ($user->canDo('import.import.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
